// ModelessDialogView.cpp : implementation of the CModelessDialogView class
//

#include "stdafx.h"
#include "ModelessDialog.h"

#include "ModelessDialogDoc.h"
#include "ModelessDialogView.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CModelessDialogView

IMPLEMENT_DYNCREATE(CModelessDialogView, CView)

BEGIN_MESSAGE_MAP(CModelessDialogView, CView)
	//{{AFX_MSG_MAP(CModelessDialogView)
	ON_COMMAND(ID_SHOW, OnShow)
	ON_COMMAND(ID_HIDE, OnHide)
	ON_UPDATE_COMMAND_UI(ID_HIDE, OnUpdateHide)
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_END_MODELESS_DIALOG, OnModelessDialogEnd)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CModelessDialogView construction/destruction

CModelessDialogView::CModelessDialogView()
	: m_pDlg( new CMyDialog )  // create the modeless dialog object on the heap
{
}

CModelessDialogView::~CModelessDialogView()
{
	delete m_pDlg;  // delete the modeless dialog object
}

BOOL CModelessDialogView::PreCreateWindow(CREATESTRUCT& cs)
{
	return CView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CModelessDialogView drawing

void CModelessDialogView::OnDraw(CDC* pDC)
{
	CModelessDialogDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);
}

/////////////////////////////////////////////////////////////////////////////
// CModelessDialogView diagnostics

#ifdef _DEBUG
void CModelessDialogView::AssertValid() const
{
	CView::AssertValid();
}

void CModelessDialogView::Dump(CDumpContext& dc) const
{
	CView::Dump(dc);
}

CModelessDialogDoc* CModelessDialogView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CModelessDialogDoc)));
	return (CModelessDialogDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CModelessDialogView message handlers

void CModelessDialogView::OnShow() 
{
	ASSERT(m_pDlg);
	if (m_pDlg->GetSafeHwnd() == NULL)  // if the dialog does not already exist
	{
		// create it
		m_pDlg->SetManagerView( this );
		m_pDlg->Create();
	}
	else
	{
		// just set the focus to it
		m_pDlg->SetFocus();
	}
}

void CModelessDialogView::OnHide() 
{
	ASSERT(m_pDlg);
	m_pDlg->DestroyWindow();  // destroy it
}

void CModelessDialogView::OnUpdateHide(CCmdUI* pCmdUI) 
{
	ASSERT(m_pDlg);
	pCmdUI->Enable( m_pDlg->GetSafeHwnd() != NULL );
}

LRESULT CModelessDialogView::OnModelessDialogEnd(WPARAM, LPARAM)
{
	OnHide();
	return 0L;
}
